<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    round
    closeable
    position="top"
    :style="{ height: '42%' }"
  >
    <div class="query-search-popup">
      <div class="title">条件查询</div>
      <van-form label-width="80px">
        <van-field
          name="caseType"
          label="目标名称"
          input-align="right"
          v-model="customQueryPrams.name_"
          placeholder="请输入目标名称"
        />
        <van-field
          name="caseType"
          label="安全业务分类"
          input-align="right"
          v-model="customQueryPrams.safty_class_"
          placeholder="请选择安全业务分类"
          readonly
          clickable
          @click="saftyClassPicker = true"
        />
        <van-field
          name="caseType"
          label="目标年度"
          input-align="right"
          v-model="customQueryPrams.target_year_"
          placeholder="请选择目标年度"
          readonly
          clickable
          @click="targetYearPicker = true"
        />

        <div class="search-btn">
          <van-button class="btn-left" block type="info" native-type="button" @click="searchData">
            查询
          </van-button>
          <van-button class="btn-right" block plain type="info" native-type="button" @click="resetData">
            重置
          </van-button>
        </div>

        <!--  选择器  -->
        <template>
          <!--   安全业务分类   -->
          <van-popup v-model="saftyClassPicker" position="bottom" get-container="body">
            <van-picker
              title="安全业务分类"
              show-toolbar
              value-key="name"
              :columns="saftyClassOpt"
              @cancel="_ => {
                customQueryPrams.safty_class_ = ''
                saftyClassPicker = false
              }"
              @confirm="
                ({name}) => {
                  customQueryPrams.safty_class_ = name
                  saftyClassPicker = false
                }
              "
            />
          </van-popup>

          <!--     目标年度     -->
          <van-popup v-model="targetYearPicker" position="bottom">
            <van-datetime-picker
              class="year-picker"
              v-model="target_year_"
              type="year-month"
              title="目标年度"
              :formatter="formatter"
              @cancel="_ => {
                customQueryPrams.target_year_ = ''
                targetYearPicker = false
              }"
              @confirm="
                 time => {
                  customQueryPrams.target_year_ = moment(time).format('YYYY')
                  targetYearPicker = false
                }
              "
            />
          </van-popup>


        </template>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'

export default {
  name: 'QuerySearchPopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    // 查询对象
    customQueryPrams: {
      default: () => ({
        caseType: '',
        caseSrc: '',
        caseStatus: ''
      }),
      type: Object
    },
    saftyClassOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      saftyClassPicker: false, // 安全业务分类选择框显隐
      targetYearPicker: false, // 目标年度选择
      target_year_: '' // 目标年度
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    }
  },
  methods: {
    moment,

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    // 重置数据
    resetData() {
      /*
      * 重置数据，从父组件找到 “customQueryPrams对象” 的原始结构
      * 并还原表单原始状态
      * */
      Object.keys(this.customQueryPrams).forEach(key => {
        this.customQueryPrams[key] = this.$parent.$options.data().customQueryPrams[key]
      })
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    formatter(type, val) {
      if (type === 'year') {
        return `${val}年`
      }
      return val
    }
  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;
    position: relative;

    .search-btn {
      display: flex;
      position: absolute;
      bottom: 5%;
      width: 80%;
      transform: translateX(-50%);
      left: 50%;

      .van-button {

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

  ::v-deep .year-picker {
    .van-picker__columns {
      .van-picker-column {

        &:nth-child(2) {
          display: none;
        }
      }
    }
  }
}
</style>

